#include "MySvgWidget.h"
#include <QPainter>
#include <QDragEnterEvent>
#include <QDropEvent>
#include <Qurl>

MySvgWidget::MySvgWidget(QWidget *parent) :
	QWidget(parent)
{
	bgcolor = QColor(128, 128, 128);
}

bool MySvgWidget::load(QString path)
{
	if (path.startsWith("file:///")) {
		path = QString::fromUtf16(path.utf16() + 8);
	} else if (path.startsWith("file://")) {
		path = "\\\\" + QString::fromUtf16(path.utf16() + 7);
	}

	if (svgfile.load(path)) {
		update();
		return true;
	}
	return false;
}

void MySvgWidget::setBackgroundColor(QColor color)
{
	bgcolor = color;
	update();
}

QSvgRenderer const *MySvgWidget::renderer() const
{
	return &svgfile;
}

void MySvgWidget::paintEvent(QPaintEvent *)
{
	QPainter painter(this);
	painter.fillRect(0, 0, width(), height(), bgcolor);

	int margin = 10;
	int w = width() - margin;
	int h = height() - margin;
	QSize sz = svgfile.defaultSize();
	if (w < 1 || h < 1 || sz.width() < 1 || sz.height() < 1) {
		return;
	}
	if (h * sz.width() < w * sz.height()) {
		w = h * sz.width() / sz.height();
	} else {
		h = w * sz.height() / sz.width();
	}
	int x = (width() - w) / 2;
	int y = (height() - h) / 2;
	svgfile.render(&painter, QRect(x, y, w, h));

	painter.setPen(QColor(0, 0, 0));
	painter.setBrush(QBrush(Qt::transparent));
	painter.drawRect(QRect(x - 1, y - 1, w + 1, h + 1));

}

void MySvgWidget::dragEnterEvent(QDragEnterEvent *event)
{
	event->accept();
}

void MySvgWidget::dropEvent(QDropEvent *event)
{
	if (event->mimeData()->urls().size() == 1) {
		QString path = event->mimeData()->urls()[0].toString();
		load(path);
	}
}

